@@ -1,7 +1,7 @@
 package App::CryptoCurrencyUtils;
 
-our $DATE = '2018-01-31'; # DATE
-our $VERSION = '0.009'; # VERSION
+our $DATE = '2018-02-05'; # DATE
+our $VERSION = '0.010'; # VERSION
 
 use 5.010001;
 use strict;
@@ -324,6 +324,57 @@ sub list_exchanges {
     [200, "OK", [CryptoExchange::Catalog->new->all_data]];
 }
 
+$SPEC{list_cmc_coins} = {
+    v => 1.1,
+    summary => "List of all coins listed on coinmarketcap.com (CMC) ".
+        "along with their marketcaps, ranks, etc",
+    description => <<'_',
+
+This utility basically parses <https://coinmarketcap.com/all/views/all/> into
+table data.
+
+_
+    args => {
+    },
+};
+sub list_cmc_coins {
+    require HTTP::Tiny;
+
+    my $res = HTTP::Tiny->new->get("https://coinmarketcap.com/all/views/all/");
+    return [$res->{status}, $res->{reason}] unless $res->{success};
+
+    my @coins;
+
+    # we capture the records first to speed up otherwise-glacial matching
+    my @trs;
+    while ($res->{content} =~ m!(<tr \s id="id-[\w-]+".+?</tr>)!gsx) {
+        push @trs, $1;
+    }
+    #say "D:found ", scalar(@trs), " coins";
+
+    my $i = 0;
+    for my $tr (@trs) {
+        $i++;
+        $tr =~
+            m!<tr \s id="id-(?<safename>[\w-]+)"[^>]*>.+?
+              <td \s class="text-center">\s*(?<rank>\d+)\s*</td>.+?
+              <td \s class="[^"]*?col-symbol">(?<symbol>[^<]+)<.+?
+              <td \s class="[^"]*?market-cap[^"]*" \s data-usd="(?<mktcap_usd>[^"]+)" \s data-btc="(?<mktcap_btc>[^"]+)".+?
+              <a \s href="[^"]+" \s class="price" \s data-usd="(?<price_usd>[^"]+)" \s data-btc="(?<price_btc>[^"]+)".+?
+              \s data-supply="(?<supply>[^"]+)".+?
+              <a \s href="[^"]+" \s class="volume" \s data-usd="(?<volume_usd>[^"]+)" \s data-btc="(?<volume_btc>[^"]+)".+?
+             !sx
+                 or die "Can't parse row #$i";
+        push @coins, {%+};
+    }
+
+    my $resmeta = {
+        'table.fields'       => [qw/rank safename symbol mktcap_usd mktcap_btc price_usd price_btc supply volume_usd volume_btc/],
+        #'table.field_aligns' => [qw/left left     left   right      right     right     right     right  right      right/], # ugh, makes rendering so slow
+    };
+    [200, "OK", \@coins, $resmeta];
+}
+
 1;
 # ABSTRACT: CLI utilities related to cryptocurrencies
 
@@ -339,7 +390,7 @@ App::CryptoCurrencyUtils - CLI utilities related to cryptocurrencies
 
 =head1 VERSION
 
-This document describes version 0.009 of App::CryptoCurrencyUtils (from Perl distribution App-CryptoCurrencyUtils), released on 2018-01-31.
+This document describes version 0.010 of App::CryptoCurrencyUtils (from Perl distribution App-CryptoCurrencyUtils), released on 2018-02-05.
 
 =head1 DESCRIPTION
 
@@ -355,6 +406,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<grep-exchange>
 
+=item * L<list-cmc-coins>
+
 =item * L<list-coins>
 
 =item * L<list-exchanges>
@@ -439,6 +492,33 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 list_cmc_coins
+
+Usage:
+
+ list_cmc_coins() -> [status, msg, result, meta]
+
+List of all coins listed on coinmarketcap.com (CMC) along with their marketcaps, ranks, etc.
+
+This utility basically parses L<https://coinmarketcap.com/all/views/all/> into
+table data.
+
+This function is not exported.
+
+No arguments.
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 list_coins
 
 Usage:
